@@ -11,6 +11,9 @@ from ckan.lib.search import rebuild
 
 from ckanext.resource_indexer import config
 
+def dumb_translator(string: str):
+    return string.translate(str.maketrans({"P": "X", "D": "Y", "F": "Z"}))
+
 
 @pytest.mark.usefixtures("with_plugins", "clean_db", "clean_index")
 @pytest.mark.ckan_config(
@@ -46,6 +49,32 @@ class TestPlainIndexer(object):
         result = helpers.call_action("package_search", q="hello world")
         assert result["count"] == 0
 
+    @pytest.mark.ckan_config(
+        "ckanext.resource_indexer.indexable_formats", "txt json"
+    )
+    @pytest.mark.ckan_config(
+        config.CONFIG_PLAIN_FORMATS, ["json"]
+    )
+
+    def test_plain_formats_can_be_changed(
+        self, create_with_upload, package
+    ):
+        create_with_upload(
+            "hello world", "file.txt", format="txt", package_id=package["id"]
+        )
+
+        create_with_upload(
+            "not here yet",
+            "file.json",
+            format="json",
+            package_id=package["id"],
+        )
+        result = helpers.call_action("package_search", q="hello world")
+        assert result["count"] == 0
+        result = helpers.call_action("package_search", q="not here yet")
+        assert result["count"] == 1
+
+
     @pytest.mark.ckan_config(
         "ckanext.resource_indexer.indexable_formats", "txt json"
     )
@@ -106,6 +135,22 @@ class TestPdfIndexer(object):
         result = helpers.call_action("package_search", q="Dummy PDF")
         assert result["count"] == 1
 
+    @pytest.mark.ckan_config(
+        "ckanext.resource_indexer.indexable_formats", "pdf"
+    )
+    @pytest.mark.ckan_config(
+        config.CONFIG_PFD_PROCESSOR, "ckanext.resource_indexer.tests.test_plugin:dumb_translator"
+    )
+    def test_page_processor_applied(self, create_with_upload, package):
+        path = os.path.join(os.path.dirname(__file__), "data/example.pdf")
+        with open(path, "rb") as pdf:
+            create_with_upload(
+                pdf.read(), "file.pdf", format="pdf", package_id=package["id"]
+            )
+
+        result = helpers.call_action("package_search", q="Yummy XYZ")
+        assert result["count"] == 1
+
 
 @pytest.mark.usefixtures("with_plugins")
 @pytest.mark.ckan_config("ckan.plugins", "resource_indexer")
